@@ -9,7 +9,7 @@ use File::Temp;
 use Digest::MD5 'md5_hex';
 use Digest::SHA1;
 use IO::File;
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 has [qw/cleanup path end_range ro/] => ( 
     is => 'rw',
@@ -68,15 +68,13 @@ sub add_chunk {
     $chunk //= '';
     my $handle = $self->handle;
     if ($self->start_range) {
-        #$handle->sysseek($self->start_range, SEEK_SET);
-        sysseek($handle, $self->start_range, SEEK_SET) or die "$@";
+        $handle->sysseek($self->start_range, SEEK_SET);
     }
     else {
         $handle->sysseek(0, SEEK_END);
     }
-    syswrite($handle, $chunk);
-    #croak "Can't write to asset: $!"
-    #    unless defined $handle->syswrite($chunk, length $chunk);
+    croak "Can't write to asset: $!"
+        unless defined $handle->syswrite($chunk, length $chunk);
     return $self;
 }
 
@@ -289,13 +287,13 @@ Modification time of asset.
 
 Size of asset data in bytes.
 
-=head2 md5_sum
+=head2 md5sum
 
   my $md5 = $file->md5sum;
 
 return the md5 digest in hexadecimal form file;
 
-=head2 sha1_sum
+=head2 sha1sum
 
   my $sha1 = $file->sha1sum;
 
